module.exports = defineTest({
	description: 'updates to names are preserved (#930)'
});
